@@ -23,5 +23,5 @@ class Command(BaseCommand):
         except Exception as e:
             self.stdout.write(self.style.ERROR(str(e)))
             return
-        self.stdout.write(self.style.SUCCESS('  ✓  ') + 'Successfully Simple Pages created')
+        self.stdout.write(self.style.SUCCESS('  ✓  ') + 'Successful! Simple Pages created')
         return
\ No newline at end of file
